package de.ids_mannheim.korap.openthesaurus;

import org.junit.jupiter.api.DisplayName;
import org.junit.jupiter.api.Test;

import java.io.BufferedInputStream;
import java.io.IOException;
import java.nio.charset.StandardCharsets;
import java.nio.file.Files;
import java.nio.file.Path;
import java.util.zip.ZipEntry;
import java.util.zip.ZipOutputStream;

import static org.junit.jupiter.api.Assertions.assertEquals;

public class OpenThesaurusDataTest {

    String newLine = System.getProperty("line.separator");
    String testData = String.join(newLine,
            "Atomspaltung;Kernspaltung (fachspr., technisch);Fission;Kernfission",
            "Wiederaufnahme;Fortführung",
            "davonfahren;aufbrechen;davonbrausen;abfahren;abzischen (ugs.);abhauen (ugs.);abdüsen (ugs.)",
            newLine,
            "============================================================="
    );

    @Test
    @DisplayName("Downloaded/extracted file should have the same content as the original string")
    void getFileTest() throws IOException {
        Path tempFileOriginal = Files.createTempFile("temp", ".zip");
        Path tempFileTest = Files.createTempFile("temp", ".txt");
        ZipOutputStream ZOS = new ZipOutputStream(Files.newOutputStream(tempFileOriginal));
        ZOS.putNextEntry(new ZipEntry(tempFileOriginal.toString()));
        byte[] bytesOut = testData.getBytes(StandardCharsets.UTF_8);
        ZOS.write(bytesOut, 0, bytesOut.length);
        ZOS.close();

        OpenThesaurusData.getFile(tempFileOriginal.toString(), tempFileTest.toString());

        BufferedInputStream BIS = new BufferedInputStream(Files.newInputStream(tempFileTest));
        byte[] bytesIn = BIS.readAllBytes();
        BIS.close();

        tempFileOriginal.toFile().delete();
        tempFileTest.toFile().delete();

        assertEquals(testData, new String(bytesIn));
    }
}
